camelot.view.controls.delegates.texteditdelegate — Camelot documentation

### Navigation

- index
- modules |
- Camelot documentation »
- Module code »
- camelot.view.controls.delegates »

# Source code for camelot.view.controls.delegates.texteditdelegate

    #  ============================================================================
    #
    #  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
    #  www.conceptive.be / project-camelot@conceptive.be
    #
    #  This file is part of the Camelot Library.
    #
    #  This file may be used under the terms of the GNU General Public
    #  License version 2.0 as published by the Free Software Foundation
    #  and appearing in the file license.txt included in the packaging of
    #  this file.  Please review this information to ensure GNU
    #  General Public Licensing requirements will be met.
    #
    #  If you are unsure which license is appropriate for your use, please
    #  visit www.python-camelot.com or contact project-camelot@conceptive.be
    #
    #  This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
    #  WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
    #
    #  For use of this library in commercial applications, please contact
    #  project-camelot@conceptive.be
    #
    #  ============================================================================
    from PyQt4.QtCore import Qt

    from customdelegate import CustomDelegate, DocumentationMetaclass
    from camelot.view.controls import editors
    from camelot.view.proxy import ValueLoading
    from camelot.core.utils import ugettext, variant_to_pyobject

    class TextEditDelegate(CustomDelegate):
        """Custom delegate for simple string values"""

        __metaclass__ = DocumentationMetaclass

        editor = editors.TextEditEditor

        def __init__(self, parent=None, **kwargs):
            CustomDelegate.__init__(self, parent, **kwargs)

        def paint(self, painter, option, index):
            painter.save()
            self.drawBackground(painter, option, index)
            value = variant_to_pyobject( index.model().data( index, Qt.EditRole ) )

            value_str = u''
            if value not in (None, ValueLoading):
                value_str = ugettext(value)

            self.paint_text(painter, option, index, value_str)
            painter.restore()

### Navigation

- index
- modules |
- Camelot documentation »
- Module code »
- camelot.view.controls.delegates »

Comments
blog comments powered by Disqus